@@ -32,42 +32,41 @@
 #endif
 
 #include "mbfilter.h"
-#include "mbfilter_iso8859_3.h"
-#include "unicode_table_iso8859_3.h"
+#include "mbfilter_iso8859_1.h"
 
-static const char *mbfl_encoding_8859_3_aliases[] = {"ISO_8859-3", "latin3", NULL};
+static const char *mbfl_encoding_8859_1_aliases[] = {"ISO_8859-1", "latin1", NULL};
 
-const mbfl_encoding mbfl_encoding_8859_3 = {
-	mbfl_no_encoding_8859_3,
-	"ISO-8859-3",
-	"ISO-8859-3",
-	(const char *(*)[])&mbfl_encoding_8859_3_aliases,
+const mbfl_encoding mbfl_encoding_8859_1 = {
+	mbfl_no_encoding_8859_1,
+	"ISO-8859-1",
+	"ISO-8859-1",
+	(const char *(*)[])&mbfl_encoding_8859_1_aliases,
 	NULL,
 	MBFL_ENCTYPE_SBCS
 };
 
-const struct mbfl_identify_vtbl vtbl_identify_8859_3 = {
-	mbfl_no_encoding_8859_3,
+const struct mbfl_identify_vtbl vtbl_identify_8859_1 = {
+	mbfl_no_encoding_8859_1,
 	mbfl_filt_ident_common_ctor,
 	mbfl_filt_ident_common_dtor,
 	mbfl_filt_ident_true
 };
 
-const struct mbfl_convert_vtbl vtbl_8859_3_wchar = {
-	mbfl_no_encoding_8859_3,
+const struct mbfl_convert_vtbl vtbl_8859_1_wchar = {
+	mbfl_no_encoding_8859_1,
 	mbfl_no_encoding_wchar,
 	mbfl_filt_conv_common_ctor,
 	mbfl_filt_conv_common_dtor,
-	mbfl_filt_conv_8859_3_wchar,
+	mbfl_filt_conv_8859_1_wchar,
 	mbfl_filt_conv_common_flush
 };
 
-const struct mbfl_convert_vtbl vtbl_wchar_8859_3 = {
+const struct mbfl_convert_vtbl vtbl_wchar_8859_1 = {
 	mbfl_no_encoding_wchar,
-	mbfl_no_encoding_8859_3,
+	mbfl_no_encoding_8859_1,
 	mbfl_filt_conv_common_ctor,
 	mbfl_filt_conv_common_dtor,
-	mbfl_filt_conv_wchar_8859_3,
+	mbfl_filt_conv_wchar_8859_1,
 	mbfl_filt_conv_common_flush
 };
 
@@ -75,58 +74,20 @@ const struct mbfl_convert_vtbl vtbl_wchar_8859_3 = {
 #define CK(statement)	do { if ((statement) < 0) return (-1); } while (0)
 
 /*
- * ISO-8859-3 => wchar
+ * ISO-8859-1 => wchar
  */
-int mbfl_filt_conv_8859_3_wchar(int c, mbfl_convert_filter *filter)
+int mbfl_filt_conv_8859_1_wchar(int c, mbfl_convert_filter *filter)
 {
-	int s;
-
-	if (c >= 0 && c < 0xa0) {
-		s = c;
-	} else if (c >= 0xa0 && c < 0x100) {
-		s = iso8859_3_ucs_table[c - 0xa0];
-		if (s <= 0) {
-			s = c;
-			s &= MBFL_WCSPLANE_MASK;
-			s |= MBFL_WCSPLANE_8859_3;
-		}
-	} else {
-		s = c;
-		s &= MBFL_WCSGROUP_MASK;
-		s |= MBFL_WCSGROUP_THROUGH;
-	}
-
-	CK((*filter->output_function)(s, filter->data));
-
-	return c;
+	return (*filter->output_function)(c, filter->data);
 }
 
 /*
- * wchar => ISO-8859-3
+ * wchar => ISO-8859-1
  */
-int mbfl_filt_conv_wchar_8859_3(int c, mbfl_convert_filter *filter)
+int mbfl_filt_conv_wchar_8859_1(int c, mbfl_convert_filter *filter)
 {
-	int s, n;
-
-	if (c >= 0 && c < 0xa0) {
-		s = c;
-	} else {
-		s = -1;
-		n = 95;
-		while (n >= 0) {
-			if (c == iso8859_3_ucs_table[n]) {
-				s = 0xa0 + n;
-				break;
-			}
-			n--;
-		}
-		if (s <= 0 && (c & ~MBFL_WCSPLANE_MASK) == MBFL_WCSPLANE_8859_3) {
-			s = c & MBFL_WCSPLANE_MASK;
-		}
-	}
-
-	if (s >= 0) {
-		CK((*filter->output_function)(s, filter->data));
+	if (c >= 0 && c < 0x100) {
+		CK((*filter->output_function)(c, filter->data));
 	} else {
 		if (filter->illegal_mode != MBFL_OUTPUTFILTER_ILLEGAL_MODE_NONE) {
 			CK(mbfl_filt_conv_illegal_output(c, filter));
